Learn R Programming

NetworkToolbox (version 1.3.2)

node.multidimensional: Detects Node Crossings in a Network

Description

UNDER DEVELOPMENT. Computes rspbc for connections between dimensions in a network. Multidimensional nodes can be detected

Usage

node.multidimensional(A, comm, plot = FALSE)

Arguments

A

An adjacency matrix of network data

comm

A vector or matrix corresponding to the community each node belongs to

plot

Should a plot be produced?

Value

Produces a list containing:

Examples

Run this code
# NOT RUN {
# Pearson's correlation only for CRAN checks
A <- TMFG(neoOpen, normal = FALSE)$A

# }
# NOT RUN {
# Better to use polychoric correlations with this dataset
ega.glasso <- EGAnet::EGA(neoOpen)

result <- node.multidimensional(A = ega.glasso$network, comm = ega.glasso$wc, plot = FALSE)

# }
# NOT RUN {
# }

Run the code above in your browser using DataLab