Learn R Programming

NetworkToolbox (version 1.3.2)

node.redundant: Detects Redundant Nodes in a Network

Description

Identifies redundant nodes in the network based on several measures. Computes the weighted topological overlap between each node and every other node in the network. The weighted topological overlap is implemented using the method from Nowick et al. (2009; see references) and the function wTO from the wTO package.

Usage

node.redundant(A, sig, type = c("wTO", "pcor"), method = c("alpha",
  "bonferroni", "FDR", "adapt"))

Arguments

A

Matrix or data frame. An adjacency matrix of network data (if type = "wTO"). Dataset (if type = "pcor")

sig

Numeric. p-value for significance of overlap (defaults to .05). If more than 200 connections, then fdrtool is used to correct for false positives. In these instances, sig sets the q-value for significance of overlap (defaults to .10)

type

Character. Computes weighted topological overlap ("wTO") or partial correlations ("pcor")

method

Character. Computes significance using the standard p-value ("alpha"), bonferonni corrected p-value ("bonferroni"), false-discovery rate corrected p-value ("FDR"), or adaptive alpha p-value (adapt.a). Defaults to "alpha"

Value

Returns a list with vectors nested within the list corresponding to redundant nodes with the name of object in the list

References

#wTO Nowick, K., Gernat, T., Almaas, E., & Stubbs, L. (2009). Differences in human and chimpanzee gene expression patterns define an evolving network of transcription factors in brain. Proceedings of the National Academy of Sciences, 106, 22358-22363. doi: 10.1073/pnas.0911376106

Examples

Run this code
# NOT RUN {
# normal set to FALSE for CRAN tests
net <- TMFG(neoOpen, normal = FALSE)$A

# weighted topological overlap
result <- node.redundant(A = net, method = "adapt", type = "wTO")

# partial correlation
result <- node.redundant(A = neoOpen, method = "adapt", type = "pcor")

# }

Run the code above in your browser using DataLab